chilp

Package Version Hex Docs

gleam add chilp@2

Usage

Make sure to call chilp.register() in your main() function, and after that you can use chilp.widget() anywhere you want to place the comment widget! It’ll take two labeled options, bluesky: and mastodon:, which take ‘anchors’ to the posts you want to load your comments from.

Do your Chilp widgets look a little bleak? See Styling Chilp!

Further documentation can be found at https://hexdocs.pm/chilp.

Examples

Commands

Chilp’s power is that it can rely on other backends to provide moderation, user verification, etc. However, sometimes you may want to create some custom behaviour for your site specifically. In that case, you should be able to add a comment to any offending comments to this end which Chilp recognises and processes. Chilp commands are prefixed like -chilp <command>.

Development

cd examples/lustre_chilp_app
bun install
just run-example
Search Document