chilp/widget/anchors

Types

pub type Bluesky {
  Bluesky(did: String, postid: String)
}

Constructors

  • Bluesky(did: String, postid: String)

    Arguments

    did

    Your DID, for @strawmelonjuice.com, this looks like "did:plc:jgtfsmv25thfs4zmydtbccnn".

    Not sure how to find your DID? https://bsky-did.neocities.org is one of the many places where you can easily find it.

    postid

    A post id to bind to, you’ll find this in a post url https://bsky.app/profile/<your-username-or-did>/post/[postid]

pub type Mastodon {
  Mastodon(instance: String, postid: String)
}

Constructors

  • Mastodon(instance: String, postid: String)

    Arguments

    instance

    The instance name, e.g. mastodon.social, this is where your post is stored, and where chilp will attempt to fetch it from.

    postid

    A post id to bind to, you’ll find this in a post url https://mastodon.social/@<username>/[postid].

Search Document