chilp

Package Version Hex Docs

gleam add chilp@1

Usage

You can use chilp as any Lustre component, the main module has an easy builder which allows you to input typed Anchors (links to posts from which we fetch comments) instead of using attributes. If you prefer, you could also use widget.element() or create a Chilp widget yourself using element.element. As long as widget.register() is ran Chilp should be able to pick it up.

Examples

Commands

Chilp’s power is that it can rely on other backends to provide moderation, user verification, etc. However, sometimes you may want to create some custom behaviour for your site specifically. In that case, you should be able to add a comment to any offending comments to this end which Chilp recognises and processes. Chilp commands are prefixed like -chilp <command>.

Further documentation can be found at https://hexdocs.pm/chilp.

Development

cd examples/lustre_chilp_app
bun install
tailwindcss -i ./src/input.css -o ./assets/styled.css
gleam run -m lustre/dev start
Search Document