chilp
Values
pub const widget: fn(
option.Option(anchors.Mastodon),
option.Option(anchors.Bluesky),
) -> element.Element(a)
Widget component!
Before adding this component make sure to call widget.register() to register it!
pub const widget: fn(
option.Option(anchors.Mastodon),
option.Option(anchors.Bluesky),
) -> element.Element(a)
Widget component!
Before adding this component make sure to call widget.register() to register it!